@@ -75,6 +75,8 @@ module Stomp
     #     :max_hbrlck_fails => 0,
     #     :fast_hbs_adjust => 0.0,
     #     :connread_timeout => 0,
+    #     :tcp_nodelay => true,
+    #     :start_timeout => 10,
     #   }
     #
     #   e.g. c = Stomp::Connection.new(hash)
@@ -123,6 +125,8 @@ module Stomp
         @max_hbrlck_fails = 0 # 0 means never retry for HB read lock failures
         @fast_hbs_adjust = 0.0 # Fast heartbeat senders sleep adjustment
         @connread_timeout = 0 # Connect read CONNECTED/ERROR timeout
+        @tcp_nodelay = true # Disable Nagle
+        @start_timeout = 10 # Client only, startup timeout
         warn "login looks like a URL, do you have the correct parameters?" if @login =~ /:\/\//
       end
 
@@ -142,7 +146,8 @@ module Stomp
     # hashed_initialize prepares a new connection with a Hash of initialization
     # parameters.
     def hashed_initialize(params)
-      @parameters = refine_params(params)
+      lp = _hdup(params)
+      @parameters = refine_params(lp)
       @reliable =  @parameters[:reliable]
       @reconnect_delay = @parameters[:initial_reconnect_delay]
       @connect_headers = @parameters[:connect_headers]
@@ -158,6 +163,13 @@ module Stomp
       @max_hbrlck_fails = @parameters[:max_hbrlck_fails]
       @fast_hbs_adjust = @parameters[:fast_hbs_adjust]
       @connread_timeout = @parameters[:connread_timeout]
+      #
+      # Try to support Ruby 1.9.x and 2.x ssl.
+      unless defined?(RSpec)
+        @parameters[:hosts].each do |ah|
+          ah[:ssl] = Stomp::SSLParams.new if ah[:ssl] == true
+        end
+      end
       #sets the first host to connect
       change_host
     end
@@ -183,7 +195,7 @@ module Stomp
       headers = headers.symbolize_keys
       headers[:transaction] = name
       _headerCheck(headers)
-      @logger.on_begin(log_params, headers)
+      slog(:on_begin, log_params, headers)
       transmit(Stomp::CMD_BEGIN, headers)
     end
 
@@ -214,7 +226,7 @@ module Stomp
           headers[:'message-id'] = message_id
       end
       _headerCheck(headers)
-      @logger.on_ack(log_params, headers)
+      slog(:on_ack, log_params, headers)
       transmit(Stomp::CMD_ACK, headers)
     end
 
@@ -226,11 +238,11 @@ module Stomp
       headers = headers.symbolize_keys
       case @protocol
         when Stomp::SPL_12
-          # The ACK frame MUST include an id header matching the ack header 
+          # The NACK frame MUST include an id header matching the ack header 
           # of the MESSAGE being acknowledged.
           headers[:id] = message_id
         else # Stomp::SPL_11 only
-          # ACK has two REQUIRED headers: message-id, which MUST contain a value 
+          # NACK has two REQUIRED headers: message-id, which MUST contain a value 
           # matching the message-id for the MESSAGE being acknowledged and 
           # subscription, which MUST be set to match the value of the subscription's 
           # id header.
@@ -238,7 +250,7 @@ module Stomp
           raise Stomp::Error::SubscriptionRequiredError unless headers[:subscription]
       end
       _headerCheck(headers)
-      @logger.on_nack(log_params, headers)
+      slog(:on_nack, log_params, headers)
       transmit(Stomp::CMD_NACK, headers)
     end
 
@@ -248,7 +260,7 @@ module Stomp
       headers = headers.symbolize_keys
       headers[:transaction] = name
       _headerCheck(headers)
-      @logger.on_commit(log_params, headers)
+      slog(:on_commit, log_params, headers)
       transmit(Stomp::CMD_COMMIT, headers)
     end
 
@@ -258,7 +270,7 @@ module Stomp
       headers = headers.symbolize_keys
       headers[:transaction] = name
       _headerCheck(headers)
-      @logger.on_abort(log_params, headers)
+      slog(:on_abort, log_params, headers)
       transmit(Stomp::CMD_ABORT, headers)
     end
 
@@ -273,7 +285,7 @@ module Stomp
         headers[:id] = subId if headers[:id].nil?
       end
       _headerCheck(headers)
-      @logger.on_subscribe(log_params, headers)
+      slog(:on_subscribe, log_params, headers)
 
       # Store the subscription so that we can replay if we reconnect.
       if @reliable
@@ -296,7 +308,7 @@ module Stomp
         headers[:id] = subId unless headers[:id]
       end
       _headerCheck(headers)
-      @logger.on_unsubscribe(log_params, headers)
+      slog(:on_unsubscribe, log_params, headers)
       transmit(Stomp::CMD_UNSUBSCRIBE, headers)
       if @reliable
         subId = dest if subId.nil?
@@ -312,7 +324,7 @@ module Stomp
       headers = headers.symbolize_keys
       headers[:destination] = destination
       _headerCheck(headers)
-      @logger.on_publish(log_params, message, headers)
+      slog(:on_publish, log_params, message, headers)
       transmit(Stomp::CMD_SEND, headers, message)
     end
 
@@ -375,7 +387,7 @@ module Stomp
       end
       transmit(Stomp::CMD_DISCONNECT, headers)
       @disconnect_receipt = receive if headers[:receipt]
-      @logger.on_disconnect(log_params)
+      slog(:on_disconnect, log_params)
       close_socket
     end
 
@@ -398,7 +410,7 @@ module Stomp
       super_result = __old_receive()
       if super_result.nil? && @reliable && !closed?
         errstr = "connection.receive returning EOF as nil - resetting connection.\n"
-        @logger.on_miscerr(log_params, "es_recv: " + errstr)
+        slog(:on_miscerr, log_params, "es_recv: " + errstr)
         $stderr.print errstr
 
         # !!! This initiates a re-connect !!!
@@ -417,7 +429,7 @@ module Stomp
         @closed = true
         warn 'warning: broker sent EOF, and connection not reliable' unless defined?(Test)
       end
-      @logger.on_receive(log_params, super_result)
+      slog(:on_receive, log_params, super_result)
       return super_result
     end
 
@@ -480,6 +492,13 @@ module Stomp
       @hbrecv_count
     end
 
+    # log call router
+    def slog(name, *parms)
+      return false unless @logger
+      @logger.send(name, *parms) if @logger.respond_to?(:"#{name}")
+      @logger.respond_to?(:"#{name}")
+    end
+
   end # class
 
 end # module
