@@ -71,17 +71,24 @@ module Stomp
       end
     end
 
-    # ProtocolErrorConnect is raised if:
-    # * Incomplete Stomp 1.1 headers are detectd during a connect.
-    class ProtocolErrorConnect < RuntimeError
+    # ProtocolError11p - base class of 1.1 CONNECT errors
+    class ProtocolError11p < RuntimeError
       def message
-        "protocol error on CONNECT"
+        "STOMP 1.1+ CONNECT error"
+      end
+    end
+
+    # ProtocolErrorConnect is raised if:
+    # * Incomplete Stomp 1.1 headers are detected during a connect.
+    class ProtocolErrorConnect < ProtocolError11p
+      def message
+        "STOMP 1.1+ CONNECT error, missing/incorrect CONNECT headers"
       end
     end
 
     # UnsupportedProtocolError is raised if:
     # * No supported Stomp protocol levels are detected during a connect.
-    class UnsupportedProtocolError < RuntimeError
+    class UnsupportedProtocolError < ProtocolError11p
       def message
         "unsupported protocol level(s)"
       end
@@ -89,7 +96,7 @@ module Stomp
 
     # InvalidHeartBeatHeaderError is raised if:
     # * A "heart-beat" header is present, but the values are malformed.
-    class InvalidHeartBeatHeaderError < RuntimeError
+    class InvalidHeartBeatHeaderError < ProtocolError11p
       def message
         "heart-beat header value is malformed"
       end
@@ -189,6 +196,82 @@ module Stomp
     class LoggerConnectionError < RuntimeError
     end
 
+    # NilMessageError is raised if:
+    # * Invalid (nil) data is received from the Stomp server in a client's
+    # listener thread, and the connection is not reliable.
+    class NilMessageError < RuntimeError
+      def message
+        "Received message is nil, and connection not reliable"
+      end
+    end
+
+    # MalformedFailoverOptionsError is raised if failover URL
+    # options can not be parsed
+    class MalformedFailoverOptionsError < RuntimeError
+      def message
+        "failover options are malformed"
+      end
+    end
+
+    # ConnectReadTimeout is raised if:
+    # * A read for CONNECTED/ERROR is untimely
+    class ConnectReadTimeout < RuntimeError
+      def message
+        "Connect read for CONNECTED/ERROR timeout"
+      end
+    end
+
+    class StompException < RuntimeError; end
+
+    class BrokerException < StompException
+      attr_reader :headers, :message, :receipt_id, :broker_backtrace
+
+      def initialize(message)
+        @message          = message.headers.delete('message')
+        @receipt_id       = message.headers.delete('receipt-id') || 'no receipt id'
+        @headers          = message.headers
+        @broker_backtrace = message.body
+      end
+    end
+
+    class ProducerFlowControlException < BrokerException
+      attr_reader :producer_id, :dest_name
+
+      def initialize(message)
+        super(message)
+        msg_headers = /.*producer\s+\((.*)\).*to\s+prevent\s+flooding\s+([^\s]*)\.\s+/i.match(@message)
+
+        @producer_id = msg_headers && msg_headers[1]
+        @dest_name   = msg_headers && msg_headers[2]
+      end
+    end
+
+    class ProtocolException < BrokerException
+      def initialize(message)
+        super(message)
+      end
+    end
+
+    class StartTimeoutException < StompException
+      def initialize(timeout)
+        @timeout = timeout
+      end
+
+      def message
+        "Client failed to start in #{@timeout} seconds"
+      end
+    end
+
+    class ReadReceiptTimeoutException < StompException
+      def initialize(timeout)
+        @timeout = timeout
+      end
+
+      def message
+        "Read receipt not received after #{@timeout} seconds"
+      end
+    end
+
   end # module Error
 
 end # module Stomp
